@@ -2,11 +2,10 @@
 #'
 #' @name rstantools-package
 #' @aliases rstantools
-#' @docType package
 #'
 #' @description
 #' \if{html}{
-#'   \figure{stanlogo.png}{options: width="50" alt="mc-stan.org"}
+#'   \figure{logo.svg}{options: width="50" alt="mc-stan.org"}
 #' } *Stan Development Team*
 #'
 #' The \pkg{rstantools} package provides various tools for developers of \R
@@ -18,9 +17,10 @@
 #'
 #' @template seealso-vignettes
 #' @template seealso-get-help
-#' @template seealso-useR2016-video
 #'
-NULL
+#' @importFrom RcppParallel RcppParallelLibs
+#'
+"_PACKAGE"
 
 
 # internal ----------------------------------------------------------------
